@@ -1,5 +1,6 @@
 from djinja.template.base import Library
 from django.utils.importlib import import_module
+from django.conf import settings
 import jinja2
 
 register = Library()
@@ -23,13 +24,18 @@ register = Library()
 # 
 # register.tag(execute_context)
 
-from django.core import urlresolvers
 
-def url(viewname,*args,**kwargs):
+def url(view_name, *args, **kwargs):
+    from django.core.urlresolvers import reverse, NoReverseMatch
     try:
-        return urlresolvers.reverse(viewname,args=args,kwargs=kwargs)
-    except:
-        return False
+        return reverse(view_name, args=args, kwargs=kwargs)
+    except NoReverseMatch:
+        try:
+            project_name = settings.SETTINGS_MODULE.split('.')[0]
+            return reverse(project_name + '.' + view_name,
+                           args=args, kwargs=kwargs)
+        except NoReverseMatch:
+            return ''
 register.tag(url)
 
 class Load(object):
